Module api

Module api 

Provides interfaces for interacting with WSL plugin APIs.

API Module

This module provides the core functionality for interacting with the WSL plugin API. It includes abstractions for API interactions, error handling, and utility functions.

Re-exports

pub use errors::Error;
pub use errors::Result;

Modules

errors
Error Handling for WSL Plugins
utils
The utils module provides utility functions and helpers for working with the WSL Plugin API.

Structs

ApiV1
The ApiV1 struct provides an interface to interact with version 1 of the WSL Plugin API.
PreparedWSLCommand
The PreparedWSLCommand struct represents a command that has been prepared for execution within the WSL environment and can be reused without re-encoding. A command pre-encoded for the WSL Plugin API.
WSLCommand
The WSLCommand struct represents a command that can be executed within the WSL environment. A prepared command to be executed inside WSL.

Traits

WSLCommandExecution