SemverConversionError

Enum SemverConversionError 

pub enum SemverConversionError {
    PrereleaseNotSupported,
    BuildMetadataNotSupported,
    ComponentOutOfRange,
}
Available on crate feature semver only.
Errors returned when converting a semver::Version into WSLVersion.

WSLVersion only models the numeric major.minor.revision components used by the WSL plugin API. Semantic-versioning pre-release identifiers and build metadata therefore cannot be represented and are rejected.

Variants



PrereleaseNotSupported

The semantic version contains a pre-release identifier such as -alpha.1, which has no equivalent in WSLVersion.



BuildMetadataNotSupported

The semantic version contains build metadata such as +build.1, which has no equivalent in WSLVersion.



ComponentOutOfRange

One of the numeric version components does not fit into the u32 representation used by WSLVersion.