#[non_exhaustive]pub enum WSLVersionCapability {
DistributionInitPid,
DistributionRegisteredHook,
DistributionUnregisteredHook,
ExecuteBinaryInDistribution,
DistributionFlavor,
DistributionVersion,
}Expand description
WSL Plugin API capabilities that are only available from a specific API version.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DistributionInitPid
Access to WSLDistributionInformation::InitPid (2.0.5).
DistributionRegisteredHook
Notification sent when a distribution is registered (2.1.2).
DistributionUnregisteredHook
Notification sent when a distribution is unregistered (2.1.2).
ExecuteBinaryInDistribution
Execute a command inside a specific user distribution (2.1.2).
DistributionFlavor
Access to the distribution flavor field (2.4.4).
DistributionVersion
Access to the distribution version field (2.4.4).
Implementations
Sourceimpl WSLVersionCapability
impl WSLVersionCapability
Sourcepub const fn required_version(self) -> WSLVersion
pub const fn required_version(self) -> WSLVersion
Returns the minimum WSL Plugin API version required for this capability.