Module wsl_plugin_v1

Module wsl_plugin_v1 

The WSL Plugin v1 interface.

This module provides the implementation and traits required to define and interact with WSL plugins compatible with the Plugin API version 1.

WSL Plugin v1 Trait

This module defines the WSLPluginV1 trait, which provides a framework for handling synchronous notifications sent to a WSL plugin. The trait defines lifecycle events for managing the state of the WSL VM, distributions, and related settings.

Traits

WSLPluginV1
Trait defining synchronous notifications sent to the plugin.