#[repr(u32)]pub enum WSLUserConfigurationFlags {
CustomKernel = 1,
CustomKernelCommandLine = 2,
}Available on crate feature
enumflags2 only.Expand description
Represents the user configuration flags for Windows Subsystem for Linux (WSL) as enumflags2
These flags are used to customize the behavior of WSL instances based on user configuration. The values correspond to the definitions in the WSL Plugin API provided by Microsoft.
Variants
CustomKernel: Indicates that the WSL instance use use a custom Linux kernel instead of the default kernel.CustomKernelCommandLine: Specifies that the WSL instance use use a custom kernel command-line during boot.
References
See WSL Configuration for additional details on WSL user configurations.
Variants
CustomKernel = 1
A custom Linux kernel is used for the WSL instance.
CustomKernelCommandLine = 2
A custom kernel command-line is used for the WSL instance.