pub fn create_plugin_with_required_capabilities<T, I>(
api: &'static WSLPluginAPIV1,
capabilities: I,
) -> Result<T>Expand description
Creates a WSL plugin instance with a specified set of required API capabilities.
The highest required version among the provided capabilities is selected.
Errors
Returns a Windows error if the API version is insufficient or the plugin is already initialized.